import type { TraceLoaderBackend } from '@isomorphic/trace/traceLoader';
type Progress = (done: number, total: number) => undefined;
export declare class ZipTraceLoaderBackend implements TraceLoaderBackend {
    private _zipReader;
    private _entriesPromise;
    constructor(traceUri: string, progress: Progress);
    private _resolveTraceURI;
    isLive(): boolean;
    entryNames(): Promise<string[]>;
    hasEntry(entryName: string): Promise<boolean>;
    readText(entryName: string): Promise<string | undefined>;
    readBlob(entryName: string): Promise<Blob | undefined>;
}
export declare class FetchTraceLoaderBackend implements TraceLoaderBackend {
    private _entriesPromise;
    constructor(traceUri: string);
    isLive(): boolean;
    entryNames(): Promise<string[]>;
    hasEntry(entryName: string): Promise<boolean>;
    readText(entryName: string): Promise<string | undefined>;
    readBlob(entryName: string): Promise<Blob | undefined>;
    private _readEntry;
    private _readFile;
}
export {};
//# sourceMappingURL=traceLoaderBackends.d.ts.map